pub fn build_registry(
const_labels: impl IntoIterator<Item = (String, String)>,
) -> RegistryExpand description
Create the prometheus registry with const labels and process collector.
pub fn build_registry(
const_labels: impl IntoIterator<Item = (String, String)>,
) -> RegistryCreate the prometheus registry with const labels and process collector.