pub fn diff_configs(old: &ServerConfig, new: &ServerConfig) -> ConfigDiffExpand description
Compute the diff between an old and new configuration.
pub fn diff_configs(old: &ServerConfig, new: &ServerConfig) -> ConfigDiffCompute the diff between an old and new configuration.